==> 1.0.3.tar.gz: android/src/main/kotlin/com/example/shuftipro_sdk/ShuftiproSdk.kt <==
package com.example.shuftipro_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.shutipro.sdk.Shuftipro
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONObject
import java.util.*
import kotlin.collections.HashMap

/** KycPlugin */
class ShuftiproSdk: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "com.example.package_sample/sendAndroid")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
//    if (call.method == "getPlatformVersion") {
//      result.success("Android ${android.os.Build.VERSION.RELEASE}")
//    } else {
//      result.notImplemented()
//    }


    if (call.method == "sendRequest") {

      val shuftipro = Shuftipro.getInstance()

      val  authobj= call.argument<HashMap<String, Objects>>("AuthObj")
      val AuthKeys = JSONObject(authobj as Map<String, Object>)

      val  configobj= call.argument<HashMap<String,Objects>>("ConfigObj")
      val ConfigObject = JSONObject(configobj as Map<String, Object>)

      val obj = call.argument<HashMap<String,Objects>>("RequestObj")
      val requestObj = JSONObject(obj as Map<String, Object>)
      if (requestObj != null)
      {
          shuftipro.shuftiproVerification(requestObj, AuthKeys, ConfigObject, activity)
          { responseSet ->
            result.success(responseSet.toString())
          }
      }
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onDetachedFromActivity() {
    TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
    TODO("Not yet implemented")
  }
}

==> 1.0.6.tar.gz: android/src/main/kotlin/com/example/shuftipro_sdk/ShuftiproSdk.kt <==
package com.example.shuftipro_sdk

import android.app.Activity
import androidx.annotation.NonNull
import com.shutipro.sdk.Shuftipro
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import org.json.JSONObject
import java.util.*
import kotlin.collections.HashMap

/** KycPlugin */
class ShuftiproSdk: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var activity: Activity

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "com.example.package_sample/sendAndroid")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
//    if (call.method == "getPlatformVersion") {
//      result.success("Android ${android.os.Build.VERSION.RELEASE}")
//    } else {
//      result.notImplemented()
//    }


    if (call.method == "sendRequest") {

      val shuftipro = Shuftipro.getInstance()

      val  authobj= call.argument<HashMap<String, Objects>>("AuthObj")
      val AuthKeys = JSONObject(authobj as Map<String, Object>)

      val  configobj= call.argument<HashMap<String,Objects>>("ConfigObj")
      val ConfigObject = JSONObject(configobj as Map<String, Object>)

      val obj = call.argument<HashMap<String,Objects>>("RequestObj")
      val requestObj = JSONObject(obj as Map<String, Object>)
      if (requestObj != null)
      {
          shuftipro.shuftiproVerification(requestObj, AuthKeys, ConfigObject, activity)
          { responseSet ->
            result.success(responseSet.toString())
          }
      }
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onDetachedFromActivity() {
   // TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
   // TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
   // TODO("Not yet implemented")
  }
}
